"""Setup configuration for Mercury Bank API Python client.

This setup.py is kept for backward compatibility. 
The main configuration is in pyproject.toml.
"""

from setuptools import setup # type: ignore

setup()
